@@ -141,7 +141,7 @@ Returns the URL for the station's "cover art" icon image, if any.
 =item $station->B<getIconData>()
 
 Returns a two-element array consisting of the extension (ie. "png", 
-"gif", "jpeg", etc. and the actual icon image (binary data), if any.
+"gif", "jpeg", etc.) and the actual icon image (binary data), if any.
 
 =item $station->B<getImageURL>()
 
@@ -151,7 +151,7 @@ banner image.
 =item $station->B<getImageData>()
 
 Returns a two-element array consisting of the extension (ie. "png", 
-"gif", "jpeg", etc. and the actual station's banner image (binary data).
+"gif", "jpeg", etc.) and the actual station's banner image (binary data).
 
 =item $station->B<getType>()
 
@@ -375,6 +375,10 @@ sub new
 	$self->{'description'} = HTML::Entities::decode_entities($self->{'description'});
 	$self->{'description'} = uri_unescape($self->{'description'});
 	$self->{'genre'} = $1  if ($html =~ m#\"genres\"\:\s*\[\"([^\"]+)\"#s);
+	if ($self->{'genre'}) {
+		$self->{'genre'} = HTML::Entities::decode_entities($self->{'genre'});
+		$self->{'genre'} = uri_unescape($self->{'genre'});
+	}
 	print STDERR "-2: icon=".$self->{'iconurl'}."= title=".$self->{'title'}."= image=".$self->{'imageurl'}."=\n"  if ($DEBUG);
 	$self->{'cnt'} = 0;
 	while ($html =~ s#\"streamUrl\"\:\"([^\"]+)\"##s) {
