@@ -151,7 +151,7 @@ Returns the URL for the station's "cover art" icon image, if any.
 =item $station->B<getIconData>()
 
 Returns a two-element array consisting of the extension (ie. "png", 
-"gif", "jpeg", etc. and the actual icon image (binary data), if any.
+"gif", "jpeg", etc.) and the actual icon image (binary data), if any.
 
 =item $station->B<getImageURL>()
 
@@ -162,7 +162,7 @@ a separate banner image at this time.
 =item $station->B<getImageData>()
 
 Returns a two-element array consisting of the extension (ie. "png", 
-"gif", "jpeg", etc. and the actual station's banner image (binary data).
+"gif", "jpeg", etc.) and the actual station's banner image (binary data).
 
 =item $station->B<getType>()
 
@@ -410,6 +410,10 @@ sub new
 		$genreDiv =~ s#^\s*\<[^\>]*\>?##s;
 		print STDERR "--GENRE:=$genreDiv=\n"  if ($DEBUG);
 		$self->{'genre'} = $genreDiv  if ($genreDiv =~ /\w/);
+		if ($self->{'genre'}) {
+			$self->{'genre'} = HTML::Entities::decode_entities($self->{'genre'});
+			$self->{'genre'} = uri_unescape($self->{'genre'});
+		}
 		print STDERR "i:ICONURL FOUND=".$self->{'iconurl'}."= TITLE=".$self->{'title'}."=\n"  if ($DEBUG);
 		$html = '';
 	}
